@@ -10,7 +10,7 @@
 #ABSTRACT: Common methods for App::Cme
 
 package App::Cme::Common;
-$App::Cme::Common::VERSION = '1.005';
+$App::Cme::Common::VERSION = '1.006';
 use strict;
 use warnings;
 use 5.10.1;
@@ -18,6 +18,7 @@ use 5.10.1;
 use Config::Model 2.063;
 use Config::Model::Lister;
 use Pod::POM;
+use Pod::POM::View::Text;
 use Scalar::Util qw/blessed/;
 use Path::Tiny;
 
@@ -212,7 +213,7 @@ sub get_documentation {
     foreach my $s (@$sections) {
         push (@ret ,$s) if $s->title() =~ /DESCRIPTION|EXIT/;
     }
-    return join ("", map { $_->content()} @ret) . "Options:\n";;
+    return join ("", map { Pod::POM::View::Text->print($_)} @ret) . "Options:\n";;
 }
 
 1;
@@ -229,7 +230,7 @@ App::Cme::Common - Common methods for App::Cme
 
 =head1 VERSION
 
-version 1.005
+version 1.006
 
 =head1 SYNOPSIS
 
